@@ -8,7 +8,10 @@
 #' @inheritParams evaluate.fim
 #' @inheritParams Doptim
 #' @inheritParams create.poped.database
-#' @param use.laplace Should the Laplace method be used in calculating the expectation?  Currently experimental for the R-version of PopED.
+#' @param use_laplace Should the Laplace method be used in calculating the expectation of the OFV?  
+#' @param laplace.fim Should an E(FIM) be calculated when computing the Laplace approximated E(OFV).  Typically
+#' the FIM does not need to be computed and, if desired,  this calculation
+#' is done usng the standard MC integration technique, so can be slow. 
 #' 
 #' @return A list containing the E(FIM) and E(OFV(FIM)) and the a poped.db updated according  to the function arguments.
 #' 
@@ -38,14 +41,18 @@ evaluate.e.ofv.fim <- function(poped.db,
                                bLHS=poped.db$bLHS,
                                ofv_calc_type = poped.db$ofv_calc_type,
                                ED_samp_size = poped.db$ED_samp_size,
-                               use.laplace=FALSE, # not working
+                               use_laplace=poped.db$iEDCalculationType, 
+                               laplace.fim=FALSE, 
                                ...){
+
   ## update poped.db with options supplied in function
   called_args <- match.call()
   default_args <- formals()
   for(i in names(called_args)[-1]){
     if(length(grep("^poped\\.db\\$",capture.output(default_args[[i]])))==1) {
-      eval(parse(text=paste(capture.output(default_args[[i]]),"<-",called_args[[i]])))
+      #eval(parse(text=paste(capture.output(default_args[[i]]),"<-",called_args[[i]])))
+      eval(parse(text=paste(capture.output(default_args[[i]]),"<-",i)))
+      
     }
   }
   
@@ -71,14 +78,17 @@ evaluate.e.ofv.fim <- function(poped.db,
   E_fim <- NULL
   E_ofv <- NULL
   
-  if(!use.laplace){
+  if(!use_laplace){
     output <- ed_mftot(model_switch,groupsize,ni,xt,x,a,bpop,d,covd,sigma,docc,poped.db)
     E_fim <- output$ED_fim
     E_ofv <- output$ED_ofv
     poped.db=output$globalStructure
   } else { 
-    stop("Laplce method not yet implemented in R version of PopED")
-    #E_ofv  <- ed_laplace_ofv(c(),0, 0, model_switch,groupsize,ni,xt,x,a,bpop,d,covd,sigma,docc,poped.db)      
+    #stop("Laplce method not yet implemented in R version of PopED")
+    E_ofv  <- ed_laplace_ofv(model_switch,groupsize,ni,xt,x,a,bpop,d,covd,sigma,docc,poped.db)[["f"]]   
+    if(laplace.fim) {
+      E_fim <- ed_mftot(model_switch,groupsize,ni,xt,x,a,bpop,d,covd,sigma,docc,poped.db)[["ED_fim"]]
+    }
   }    
-  return(list(E_ofv=E_ofv,E_fim= E_fim, poped.db=output$globalStructure))
+  return(list(E_ofv=E_ofv,E_fim= E_fim, poped.db=poped.db))
 }
